"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_valid_path_1 = __importDefault(require("is-valid-path"));
const validator_1 = __importDefault(require("validator"));
class ValidatorBase {
    constructor() {
        this.type = 'input';
        this.name = 'BASE';
        this.message = 'OOPS! set correct message on child class.';
        this._validatorTypes = [];
    }
    get validatorTypes() {
        return this._validatorTypes;
    }
    set validatorTypes(validatorTypes) {
        this._validatorTypes = validatorTypes;
    }
    validate(testee) {
        return validatorsFor(this.validatorTypes).every(validator => validator(testee)) ? true : 'invalid value: please confirm inputs.';
    }
}
exports.ValidatorBase = ValidatorBase;
function validatorsFor(validatorTypes = []) {
    return validatorTypes.reduce((validators, validatorType) => [...validators, validatorFor(validatorType)], []);
    function validatorFor(validatorType) {
        switch (validatorType) {
            case ValidatorType.exists:
                return (arg) => arg !== null && arg !== undefined && arg !== '';
            case ValidatorType.stringType:
                return (arg) => typeof arg === 'string';
            case ValidatorType.numberType:
                return (arg) => arg && !isNaN(Number(arg));
            case ValidatorType.alphanumeric:
                return (arg) => arg && /^[a-zA-Z0-9]+$/.test(arg);
            case ValidatorType.alphanumericSymbol:
                return (arg) => arg && /^[a-zA-Z0-9_-]+$/.test(arg);
            case ValidatorType.path:
                return (arg) => arg && is_valid_path_1.default(`${arg}`);
            case ValidatorType.port:
                return (arg) => validator_1.default.isPort(`${arg}`);
            case ValidatorType.URL:
                return (arg) => arg && (validator_1.default.isURL(arg) || /^http(|s):\/\/localhost*/.test(arg));
            default:
                throw Error(`unexpected validator type: ${validatorTypes}`);
        }
    }
}
var ValidatorType;
(function (ValidatorType) {
    ValidatorType["exists"] = "exists";
    ValidatorType["stringType"] = "stringType";
    ValidatorType["numberType"] = "numberType";
    ValidatorType["alphanumeric"] = "alphanumeric";
    ValidatorType["alphanumericSymbol"] = "alphanumericSymbol";
    ValidatorType["port"] = "isPort";
    ValidatorType["path"] = "path";
    ValidatorType["URL"] = "URL";
})(ValidatorType = exports.ValidatorType || (exports.ValidatorType = {}));
var ValidatorKey;
(function (ValidatorKey) {
    ValidatorKey["SdkKey"] = "sdk_key";
    ValidatorKey["ManagementUrl"] = "management_url";
})(ValidatorKey = exports.ValidatorKey || (exports.ValidatorKey = {}));
